==> jc-1.4.0.tar.gz: soot/tagkit/TagManager.h <==
// public class soot.tagkit.TagManager

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9e7678d31a70a531 soot_tagkit_TagManager

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_TagManager_H_
#define _JC_soot_tagkit_TagManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_tagkit_Tag$object;
struct _jc_soot_tagkit_TagManager$object;
struct _jc_soot_tagkit_TagPrinter$object;

// Typedefs
typedef struct _jc_soot_tagkit_TagManager$sub_refs	_jc_soot_tagkit_TagManager$sub_refs;
typedef struct _jc_soot_tagkit_TagManager$sub_nonrefs	_jc_soot_tagkit_TagManager$sub_nonrefs;
typedef struct _jc_soot_tagkit_TagManager$refs	_jc_soot_tagkit_TagManager$refs;
typedef struct _jc_soot_tagkit_TagManager$nonrefs	_jc_soot_tagkit_TagManager$nonrefs;
typedef struct _jc_soot_tagkit_TagManager$object	_jc_soot_tagkit_TagManager$object;

typedef const struct _jc_soot_tagkit_TagManager$vmethods	_jc_soot_tagkit_TagManager$vmethods;
typedef const struct _jc_soot_tagkit_TagManager$vtable	_jc_soot_tagkit_TagManager$vtable;
typedef const struct _jc_soot_tagkit_TagManager$vtype	_jc_soot_tagkit_TagManager$vtype;

// Constructors
extern void _jc_soot_tagkit_TagManager$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_tagkit_TagManager$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern struct _jc_object *_jc_soot_tagkit_TagManager$method$getTagFor$d346ea7a178fc0ff(_jc_env *, struct _jc_soot_tagkit_TagManager$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_TagManager$method$print$ec2b3e4722a20d7e(_jc_env *, struct _jc_soot_tagkit_TagManager$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern void _jc_soot_tagkit_TagManager$method$setTagPrinter$5fc7e593a554ea09(_jc_env *, struct _jc_soot_tagkit_TagManager$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_TagManager$method_info$getTagFor$d346ea7a178fc0ff;
extern _jc_method _jc_soot_tagkit_TagManager$method_info$print$ec2b3e4722a20d7e;
extern _jc_method _jc_soot_tagkit_TagManager$method_info$setTagPrinter$5fc7e593a554ea09;

// Static methods
extern struct _jc_soot_tagkit_TagManager$object *_jc_soot_tagkit_TagManager$method$v$c216addb08f51128(_jc_env *);

// Virtual methods structure
struct _jc_soot_tagkit_TagManager$vmethods {
	struct _jc_object	*(*getTagFor$d346ea7a178fc0ff)(_jc_env *, struct _jc_soot_tagkit_TagManager$object *, struct _jc_java_lang_String$object *);
	struct _jc_java_lang_String$object	*(*print$ec2b3e4722a20d7e)(_jc_env *, struct _jc_soot_tagkit_TagManager$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
	void	(*setTagPrinter$5fc7e593a554ea09)(_jc_env *, struct _jc_soot_tagkit_TagManager$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_tagkit_TagManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_TagManager$vmethods	soot_tagkit_TagManager;
};

// Vtype
struct _jc_soot_tagkit_TagManager$vtype {
	_jc_type			type;
	_jc_soot_tagkit_TagManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_TagManager$sub_refs {
	struct _jc_object	*tagPrinter;
};

// Reference instance fields (object)
struct _jc_soot_tagkit_TagManager$refs {
    _jc_soot_tagkit_TagManager$sub_refs	soot_tagkit_TagManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_TagManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_TagManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_TagManager$sub_nonrefs	soot_tagkit_TagManager;
};

// Object instance structure
struct _jc_soot_tagkit_TagManager$object {
	_jc_soot_tagkit_TagManager$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_TagManager$vtype	*vtype;
	_jc_soot_tagkit_TagManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_TagManager$vtype _jc_soot_tagkit_TagManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_TagManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_TagManager$class_object;

#endif	/* _JC_soot_tagkit_TagManager_H_ */

==> jc-1.4.6.tar.gz: soot/tagkit/TagManager.h <==
// public class soot.tagkit.TagManager

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9e7678d31a70a531 soot_tagkit_TagManager

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_TagManager_H_
#define _JC_soot_tagkit_TagManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_tagkit_Tag$object;
struct _jc_soot_tagkit_TagManager$object;
struct _jc_soot_tagkit_TagPrinter$object;

// Typedefs
typedef struct _jc_soot_tagkit_TagManager$sub_refs	_jc_soot_tagkit_TagManager$sub_refs;
typedef struct _jc_soot_tagkit_TagManager$sub_nonrefs	_jc_soot_tagkit_TagManager$sub_nonrefs;
typedef struct _jc_soot_tagkit_TagManager$refs	_jc_soot_tagkit_TagManager$refs;
typedef struct _jc_soot_tagkit_TagManager$nonrefs	_jc_soot_tagkit_TagManager$nonrefs;
typedef struct _jc_soot_tagkit_TagManager$object	_jc_soot_tagkit_TagManager$object;

typedef const struct _jc_soot_tagkit_TagManager$vmethods	_jc_soot_tagkit_TagManager$vmethods;
typedef const struct _jc_soot_tagkit_TagManager$vtable	_jc_soot_tagkit_TagManager$vtable;
typedef const struct _jc_soot_tagkit_TagManager$vtype	_jc_soot_tagkit_TagManager$vtype;

// Constructors
extern void _jc_soot_tagkit_TagManager$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_tagkit_TagManager$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_tagkit_TagManager$method$getTagFor$d346ea7a178fc0ff(_jc_env *, struct _jc_soot_tagkit_TagManager$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_TagManager$method$print$ec2b3e4722a20d7e(_jc_env *, struct _jc_soot_tagkit_TagManager$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_tagkit_TagManager$method$setTagPrinter$5fc7e593a554ea09(_jc_env *, struct _jc_soot_tagkit_TagManager$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_TagManager$method_info$getTagFor$d346ea7a178fc0ff;
extern _jc_method _jc_soot_tagkit_TagManager$method_info$print$ec2b3e4722a20d7e;
extern _jc_method _jc_soot_tagkit_TagManager$method_info$setTagPrinter$5fc7e593a554ea09;

// Static methods
extern struct _jc_soot_tagkit_TagManager$object *_jc_soot_tagkit_TagManager$method$v$c216addb08f51128(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_tagkit_TagManager$vmethods {
	struct _jc_object	*(*getTagFor$d346ea7a178fc0ff)(_jc_env *, struct _jc_soot_tagkit_TagManager$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*print$ec2b3e4722a20d7e)(_jc_env *, struct _jc_soot_tagkit_TagManager$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*setTagPrinter$5fc7e593a554ea09)(_jc_env *, struct _jc_soot_tagkit_TagManager$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_tagkit_TagManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_TagManager$vmethods	soot_tagkit_TagManager;
};

// Vtype
struct _jc_soot_tagkit_TagManager$vtype {
	_jc_type			type;
	_jc_soot_tagkit_TagManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_TagManager$sub_refs {
	struct _jc_object	*tagPrinter;
};

// Reference instance fields (object)
struct _jc_soot_tagkit_TagManager$refs {
    _jc_soot_tagkit_TagManager$sub_refs	soot_tagkit_TagManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_TagManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_TagManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_TagManager$sub_nonrefs	soot_tagkit_TagManager;
};

// Object instance structure
struct _jc_soot_tagkit_TagManager$object {
	_jc_soot_tagkit_TagManager$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_TagManager$vtype	*vtype;
	_jc_soot_tagkit_TagManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_TagManager$vtype _jc_soot_tagkit_TagManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_TagManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_TagManager$class_object;

#endif	/* _JC_soot_tagkit_TagManager_H_ */
